Module ser

Module ser 

Structs

CommaOrSpaceSeparated
Deserializes a string into Vec by splitting on comma and/or whitespace. Used with PickFirst to accept either a delimited string or a sequence (array).
SpaceSeparated